<template>
  <card-group class="main-btn-group">
    <!-- 按钮组 -->
    <template v-slot:content>
      <btn-group :btn-list="btnList" />
    </template>
  </card-group>
</template>

<script>
import { mapGetters } from 'vuex';
import { glyphs } from '@assets/iconfont/iconfont.json';
import BtnGroup from '@/components/BtnGroup/index';
import CardGroup from '@/components/CardGroup/index';

export default {
  name: 'main-btn-group',
  components: {
    [BtnGroup.name]: BtnGroup,
    [CardGroup.name]: CardGroup
  },
  computed: {
    ...mapGetters(['mainBtnDefine', 'swingDefine']),
    ...mapGetters('machine', ['statusMap', 'blindModelArr']),
    swingData() {
      if (!Object.keys(this.statusMap).length) return [];
      const result = this.swingDefine.map(model => {
        const identifier = model.identifier;
        return { key: identifier };
      });
      return result;
    },
    btnList() {
      if (!Object.keys(this.statusMap).length) return [];
      const result = this.mainBtnDefine.map(model => {
        const identifier = model.identifier;
        if (!this.statusMap[identifier])
          return {
            icon: {},
            handler: () => {
              console.log('Undefined function');
            }
          };
        // 当前status定义
        const status = this.statusMap[identifier].status;
        // 取名称
        const defaultNameKey = `btn.${identifier}`;
        const statusNameText = status.name;
        const stateNameText = `${defaultNameKey}_${statusNameText}`;
        let name = stateNameText === this.$language(stateNameText) ? this.$language(defaultNameKey) : this.$language(stateNameText);
        if (identifier === 'FanSet' && !this.swingData.length) {
          name = '风速';
        }
        // 图标
        const icon = glyphs.some(item => item.font_class === status.icon.key) ? status.icon : { key: 'undefined', type: 'off' };
        // 是否置灰
        const gray = this.blindModelArr.includes(identifier);
        // 是否隐藏
        const hide = status.icon.key === 'disable';
        // 执行的方法
        const handler = (identifier, disable = false) => {
          disable || this.$stateMachine.nextStatus(identifier);
        };
        return { key: identifier, name, icon, gray, hide, handler };
      });
      // console.log("result",result);
      return result;
    }
  }
};
</script>

<style lang="scss">
.main-btn-group {
  position: sticky !important;
  position: -webkit-sticky !important;
  top: 1px !important;
  z-index: 3;
  width: 100%;
  height: auto;
  background-color: transparent;
  display: flex;
  justify-content: center;
  padding-bottom: 8px;
  // .select {
  // .icon {
  // box-shadow: 0 9px 27px 3px rgba(14, 110, 227, 0.3) !important;
  // }
  // }
  #btn-group-Pow {
    .icon {
      color: #fff;
      background: linear-gradient(#90c3f0, #8394d8) !important;
      box-shadow: 0 6px 18px 2px rgba(124, 145, 202, 0.5) !important;
    }
  }
}
</style>
